@@ -6,6 +6,7 @@
 from transaction import Transaction
 
 
+#: conversion table CSB - Homebank for pay modes
 PAYMODES = {'01': '2',
             '02': '2',
             '04': '3',
@@ -16,11 +17,20 @@ def convertFromCsb(csb):
     '''
     Convert a CSB43 file into a HomeBank CSV file
 
-    Args:
-        :csb: (csb43.File)
+    :param csb: a CSB43 file
+    :type csb: :class:`csb43.csb43.File`
 
-    Return:
-        list of (homebank.Transaction)
+    :rtype: :class:`list` of :class:`Transaction`
+
+    >>> # Homebank
+    >>> from csb43 import csb_43, homebank
+    >>> #
+    >>> csbFile = csb_43.File(open("movimientos.csb"), strict=False)
+    >>> #
+    >>> # print to stdout
+    >>> for line in homebank.convertFromCsb(csbFile):
+    ...    print line
+    ...
     '''
 
     for ac in csb.accounts:
@@ -34,8 +44,6 @@ def convertFromCsb(csb):
             record.info = t.ownItem
             record.payee = t.reference1.rstrip(' ')
 
-            print t.optionalItems
-
             info = ["%s: %s" % (x.item1.rstrip(' '), x.item2.rstrip(' '))
                     for x in t.optionalItems]
             record.description = "/".join(info)
